from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Carray:
	"""Carray commands group definition. 17 total commands, 5 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("carray", core, parent)

	@property
	def circular(self):
		"""circular commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_circular'):
			from .Circular import Circular
			self._circular = Circular(self._core, self._cmd_group)
		return self._circular

	@property
	def element(self):
		"""element commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_element'):
			from .Element import Element
			self._element = Element(self._core, self._cmd_group)
		return self._element

	@property
	def hexagonal(self):
		"""hexagonal commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_hexagonal'):
			from .Hexagonal import Hexagonal
			self._hexagonal = Hexagonal(self._core, self._cmd_group)
		return self._hexagonal

	@property
	def linear(self):
		"""linear commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_linear'):
			from .Linear import Linear
			self._linear = Linear(self._core, self._cmd_group)
		return self._linear

	@property
	def rectangular(self):
		"""rectangular commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_rectangular'):
			from .Rectangular import Rectangular
			self._rectangular = Rectangular(self._core, self._cmd_group)
		return self._rectangular

	def get_cosn(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:COSN \n
		Snippet: value: float = driver.antenna.model.carray.get_cosn() \n
		Sets Cos^N of the Planar Phased Array antenna. \n
			:return: cosn: float Range: 2 to 10
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:COSN?')
		return Conversions.str_to_float(response)

	def set_cosn(self, cosn: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:COSN \n
		Snippet: driver.antenna.model.carray.set_cosn(cosn = 1.0) \n
		Sets Cos^N of the Planar Phased Array antenna. \n
			:param cosn: float Range: 2 to 10
		"""
		param = Conversions.decimal_value_to_str(cosn)
		self._core.io.write(f'ANTenna:MODel:CARRay:COSN {param}')

	# noinspection PyTypeChecker
	def get_distribution(self) -> enums.AntennaModelArray:
		"""SCPI: ANTenna:MODel:CARRay:DISTribution \n
		Snippet: value: enums.AntennaModelArray = driver.antenna.model.carray.get_distribution() \n
		Sets the aperture distribution of the Planar Phased Array antenna. \n
			:return: distribution: UNIForm| PARabolic| COSine| CSQuared| COSN| TRIangular| HAMMing| HANN
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:DISTribution?')
		return Conversions.str_to_scalar_enum(response, enums.AntennaModelArray)

	def set_distribution(self, distribution: enums.AntennaModelArray) -> None:
		"""SCPI: ANTenna:MODel:CARRay:DISTribution \n
		Snippet: driver.antenna.model.carray.set_distribution(distribution = enums.AntennaModelArray.COSine) \n
		Sets the aperture distribution of the Planar Phased Array antenna. \n
			:param distribution: UNIForm| PARabolic| COSine| CSQuared| COSN| TRIangular| HAMMing| HANN
		"""
		param = Conversions.enum_scalar_to_str(distribution, enums.AntennaModelArray)
		self._core.io.write(f'ANTenna:MODel:CARRay:DISTribution {param}')

	# noinspection PyTypeChecker
	def get_geometry(self) -> enums.Geometry:
		"""SCPI: ANTenna:MODel:CARRay:GEOMetry \n
		Snippet: value: enums.Geometry = driver.antenna.model.carray.get_geometry() \n
		Sets the geometry of the custom phased array antenna. \n
			:return: geometry: RECTangular| LINear| HEXagonal| CIRCular
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:GEOMetry?')
		return Conversions.str_to_scalar_enum(response, enums.Geometry)

	def set_geometry(self, geometry: enums.Geometry) -> None:
		"""SCPI: ANTenna:MODel:CARRay:GEOMetry \n
		Snippet: driver.antenna.model.carray.set_geometry(geometry = enums.Geometry.CIRCular) \n
		Sets the geometry of the custom phased array antenna. \n
			:param geometry: RECTangular| LINear| HEXagonal| CIRCular
		"""
		param = Conversions.enum_scalar_to_str(geometry, enums.Geometry)
		self._core.io.write(f'ANTenna:MODel:CARRay:GEOMetry {param}')

	def get_pedestal(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:PEDestal \n
		Snippet: value: float = driver.antenna.model.carray.get_pedestal() \n
		Sets the Pedestal of the Planar Phased Array antenna. \n
			:return: pedestal: float Range: 0 to 1
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:PEDestal?')
		return Conversions.str_to_float(response)

	def set_pedestal(self, pedestal: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:PEDestal \n
		Snippet: driver.antenna.model.carray.set_pedestal(pedestal = 1.0) \n
		Sets the Pedestal of the Planar Phased Array antenna. \n
			:param pedestal: float Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(pedestal)
		self._core.io.write(f'ANTenna:MODel:CARRay:PEDestal {param}')

	def clone(self) -> 'Carray':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Carray(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Psk:
	"""Psk commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("psk", core, parent)

	def get_chip_count(self) -> float:
		"""SCPI: IMPort:PDW:DATA:PSK:CHIPcount \n
		Snippet: value: float = driver.importPy.pdw.data.psk.get_chip_count() \n
		Queries the pulse parameter. \n
			:return: chip_count: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PSK:CHIPcount?')
		return Conversions.str_to_float(response)

	def get_pattern(self) -> str:
		"""SCPI: IMPort:PDW:DATA:PSK:PATTern \n
		Snippet: value: str = driver.importPy.pdw.data.psk.get_pattern() \n
		Queries the pulse parameter. \n
			:return: pattern: string
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PSK:PATTern?')
		return trim_str_response(response)

	def get_rate(self) -> float:
		"""SCPI: IMPort:PDW:DATA:PSK:RATE \n
		Snippet: value: float = driver.importPy.pdw.data.psk.get_rate() \n
		Queries the pulse parameter. \n
			:return: rate: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PSK:RATE?')
		return Conversions.str_to_float(response)

	def get_states(self) -> float:
		"""SCPI: IMPort:PDW:DATA:PSK:STATes \n
		Snippet: value: float = driver.importPy.pdw.data.psk.get_states() \n
		Queries the pulse parameter. \n
			:return: states: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PSK:STATes?')
		return Conversions.str_to_float(response)

	def get_step(self) -> float:
		"""SCPI: IMPort:PDW:DATA:PSK:STEP \n
		Snippet: value: float = driver.importPy.pdw.data.psk.get_step() \n
		Queries the pulse parameter. \n
			:return: step: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PSK:STEP?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ripple:
	"""Ripple commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ripple", core, parent)

	def get_frequency(self) -> float:
		"""SCPI: PULSe:RIPPle:FREQuency \n
		Snippet: value: float = driver.pulse.ripple.get_frequency() \n
		Sets the ripple frequency. \n
			:return: frequency: float Range: 0 to 3e+08, Unit: Hz
		"""
		response = self._core.io.query_str('PULSe:RIPPle:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: PULSe:RIPPle:FREQuency \n
		Snippet: driver.pulse.ripple.set_frequency(frequency = 1.0) \n
		Sets the ripple frequency. \n
			:param frequency: float Range: 0 to 3e+08, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'PULSe:RIPPle:FREQuency {param}')

	def get_value(self) -> float:
		"""SCPI: PULSe:RIPPle \n
		Snippet: value: float = driver.pulse.ripple.get_value() \n
		Sets the ripple level. \n
			:return: ripple: float Range: 0 to 50
		"""
		response = self._core.io.query_str('PULSe:RIPPle?')
		return Conversions.str_to_float(response)

	def set_value(self, ripple: float) -> None:
		"""SCPI: PULSe:RIPPle \n
		Snippet: driver.pulse.ripple.set_value(ripple = 1.0) \n
		Sets the ripple level. \n
			:param ripple: float Range: 0 to 50
		"""
		param = Conversions.decimal_value_to_str(ripple)
		self._core.io.write(f'PULSe:RIPPle {param}')



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Repository:
	"""Repository commands group definition. 17 total commands, 2 Subgroups, 15 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("repository", core, parent)

	@property
	def volatile(self):
		"""volatile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_volatile'):
			from .Volatile import Volatile
			self._volatile = Volatile(self._core, self._cmd_group)
		return self._volatile

	@property
	def xpol(self):
		"""xpol commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xpol'):
			from .Xpol import Xpol
			self._xpol = Xpol(self._core, self._cmd_group)
		return self._xpol

	def get_access(self) -> str:
		"""SCPI: REPository:ACCess \n
		Snippet: value: str = driver.repository.get_access() \n
		Queries information on the access rights of the current user. \n
			:return: access: permission,login,pass,Uname permission Permission of the current user, for example RW (read-write) login,pass Login/Pass=No: Password not required Login/Pass=Yes: Password required Uname User name of the current user
		"""
		response = self._core.io.query_str('REPository:ACCess?')
		return trim_str_response(response)

	def get_author(self) -> str:
		"""SCPI: REPository:AUTHor \n
		Snippet: value: str = driver.repository.get_author() \n
		Enters information on the author. \n
			:return: author: string
		"""
		response = self._core.io.query_str('REPository:AUTHor?')
		return trim_str_response(response)

	def set_author(self, author: str) -> None:
		"""SCPI: REPository:AUTHor \n
		Snippet: driver.repository.set_author(author = '1') \n
		Enters information on the author. \n
			:param author: string
		"""
		param = Conversions.value_to_quoted_str(author)
		self._core.io.write(f'REPository:AUTHor {param}')

	def get_catalog(self) -> str:
		"""SCPI: REPository:CATalog \n
		Snippet: value: str = driver.repository.get_catalog() \n
		Queries the available repository elements in the database. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('REPository:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: REPository:COMMent \n
		Snippet: value: str = driver.repository.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('REPository:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: REPository:COMMent \n
		Snippet: driver.repository.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'REPository:COMMent {param}')

	# noinspection PyTypeChecker
	def get_complexity(self) -> enums.Complexity:
		"""SCPI: REPository:COMPlexity \n
		Snippet: value: enums.Complexity = driver.repository.get_complexity() \n
		Sets the complexity level. \n
			:return: complexity: PTRain| EMITter| DIRection
		"""
		response = self._core.io.query_str('REPository:COMPlexity?')
		return Conversions.str_to_scalar_enum(response, enums.Complexity)

	def set_complexity(self, complexity: enums.Complexity) -> None:
		"""SCPI: REPository:COMPlexity \n
		Snippet: driver.repository.set_complexity(complexity = enums.Complexity.DIRection) \n
		Sets the complexity level. \n
			:param complexity: PTRain| EMITter| DIRection
		"""
		param = Conversions.enum_scalar_to_str(complexity, enums.Complexity)
		self._core.io.write(f'REPository:COMPlexity {param}')

	def set_create(self, create: List[int]) -> None:
		"""SCPI: REPository:CREate \n
		Snippet: driver.repository.set_create(create = [1, 2, 3]) \n
		Creates a repository element with the selected name. \n
			:param create: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.list_to_csv_str(create)
		self._core.io.write(f'REPository:CREate {param}')

	def get_date(self) -> str:
		"""SCPI: REPository:DATE \n
		Snippet: value: str = driver.repository.get_date() \n
		Queries the creation data. \n
			:return: date: string
		"""
		response = self._core.io.query_str('REPository:DATE?')
		return trim_str_response(response)

	def set_date(self, date: str) -> None:
		"""SCPI: REPository:DATE \n
		Snippet: driver.repository.set_date(date = '1') \n
		Queries the creation data. \n
			:param date: string
		"""
		param = Conversions.value_to_quoted_str(date)
		self._core.io.write(f'REPository:DATE {param}')

	def get_filename(self) -> str:
		"""SCPI: REPository:FILename \n
		Snippet: value: str = driver.repository.get_filename() \n
		Queries the file name of the repository archive. \n
			:return: filename: string File path, incl. file name, and extension
		"""
		response = self._core.io.query_str('REPository:FILename?')
		return trim_str_response(response)

	def get_path(self) -> str:
		"""SCPI: REPository:PATH \n
		Snippet: value: str = driver.repository.get_path() \n
		Queries the directory in that the repository archive is stored. \n
			:return: path: string
		"""
		response = self._core.io.query_str('REPository:PATH?')
		return trim_str_response(response)

	def set_remove(self, remove: str) -> None:
		"""SCPI: REPository:REMove \n
		Snippet: driver.repository.set_remove(remove = '1') \n
		Removes the selected element from the workspace. The element must not reference any child elements. Remove the referenced
		elements first. \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'REPository:REMove {param}')

	def save(self) -> None:
		"""SCPI: REPository:SAVE \n
		Snippet: driver.repository.save() \n
		Stores the repository archive. To query the storage location, use the command method RsPulseSeq.Repository.path. \n
		"""
		self._core.io.write(f'REPository:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: REPository:SAVE \n
		Snippet: driver.repository.save_with_opc() \n
		Stores the repository archive. To query the storage location, use the command method RsPulseSeq.Repository.path. \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'REPository:SAVE', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_security(self) -> enums.SecurityLevel:
		"""SCPI: REPository:SECurity \n
		Snippet: value: enums.SecurityLevel = driver.repository.get_security() \n
		Sets the security level. \n
			:return: security: LEV0| LEV1| LEV2| LEV3| LEV4
		"""
		response = self._core.io.query_str('REPository:SECurity?')
		return Conversions.str_to_scalar_enum(response, enums.SecurityLevel)

	def set_security(self, security: enums.SecurityLevel) -> None:
		"""SCPI: REPository:SECurity \n
		Snippet: driver.repository.set_security(security = enums.SecurityLevel.LEV0) \n
		Sets the security level. \n
			:param security: LEV0| LEV1| LEV2| LEV3| LEV4
		"""
		param = Conversions.enum_scalar_to_str(security, enums.SecurityLevel)
		self._core.io.write(f'REPository:SECurity {param}')

	def get_select(self) -> str:
		"""SCPI: REPository:SELect \n
		Snippet: value: str = driver.repository.get_select() \n
		Selects the repository element to which the subsequent commands apply. \n
			:return: select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		response = self._core.io.query_str('REPository:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: REPository:SELect \n
		Snippet: driver.repository.set_select(select = '1') \n
		Selects the repository element to which the subsequent commands apply. \n
			:param select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'REPository:SELect {param}')

	def get_uuid(self) -> str:
		"""SCPI: REPository:UUID \n
		Snippet: value: str = driver.repository.get_uuid() \n
		Queries the repository's Universally Unique Identifier (UUID) . \n
			:return: uuid: string
		"""
		response = self._core.io.query_str('REPository:UUID?')
		return trim_str_response(response)

	def get_version(self) -> str:
		"""SCPI: REPository:VERSion \n
		Snippet: value: str = driver.repository.get_version() \n
		Sets the repository version. \n
			:return: version: string
		"""
		response = self._core.io.query_str('REPository:VERSion?')
		return trim_str_response(response)

	def set_version(self, version: str) -> None:
		"""SCPI: REPository:VERSion \n
		Snippet: driver.repository.set_version(version = '1') \n
		Sets the repository version. \n
			:param version: string
		"""
		param = Conversions.value_to_quoted_str(version)
		self._core.io.write(f'REPository:VERSion {param}')

	def clone(self) -> 'Repository':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Repository(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Csv:
	"""Csv commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csv", core, parent)

	def set_format_py(self, format_py: List[int]) -> None:
		"""SCPI: ANTenna:MODel:USER:CSV:FORMat \n
		Snippet: driver.antenna.model.user.csv.set_format_py(format_py = [1, 2, 3]) \n
		Defines how the data in the selected *.csv file is interpreted. The settings in this command are not permanent.
		The command affects only the currently selected antenna. For description of the *.csv file format, see 'Antenna pattern
		file formats'. \n
			:param format_py: No help available
		"""
		param = Conversions.list_to_csv_str(format_py)
		self._core.io.write(f'ANTenna:MODel:USER:CSV:FORMat {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class User:
	"""User commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("user", core, parent)

	@property
	def csv(self):
		"""csv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_csv'):
			from .Csv import Csv
			self._csv = Csv(self._core, self._cmd_group)
		return self._csv

	def clear(self) -> None:
		"""SCPI: ANTenna:MODel:USER:CLEar \n
		Snippet: driver.antenna.model.user.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'ANTenna:MODel:USER:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ANTenna:MODel:USER:CLEar \n
		Snippet: driver.antenna.model.user.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ANTenna:MODel:USER:CLEar', opc_timeout_ms)

	def load(self, load: str) -> None:
		"""SCPI: ANTenna:MODel:USER:LOAD \n
		Snippet: driver.antenna.model.user.load(load = '1') \n
		Loads a custom antenna pattern file. \n
			:param load: string
		"""
		param = Conversions.value_to_quoted_str(load)
		self._core.io.write(f'ANTenna:MODel:USER:LOAD {param}')

	def clone(self) -> 'User':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = User(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def get_id(self) -> float:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:SELect:ID \n
		Snippet: value: float = driver.pulse.mop.plugin.variable.select.get_id() \n
		Selects a plugin variable ID. \n
			:return: idn: float
		"""
		response = self._core.io.query_str('PULSe:MOP:PLUGin:VARiable:SELect:ID?')
		return Conversions.str_to_float(response)

	def set_id(self, idn: float) -> None:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:SELect:ID \n
		Snippet: driver.pulse.mop.plugin.variable.select.set_id(idn = 1.0) \n
		Selects a plugin variable ID. \n
			:param idn: float
		"""
		param = Conversions.decimal_value_to_str(idn)
		self._core.io.write(f'PULSe:MOP:PLUGin:VARiable:SELect:ID {param}')

	def get_value(self) -> str:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:SELect \n
		Snippet: value: str = driver.pulse.mop.plugin.variable.select.get_value() \n
		Selects a plugin variable. \n
			:return: select: string
		"""
		response = self._core.io.query_str('PULSe:MOP:PLUGin:VARiable:SELect?')
		return trim_str_response(response)

	def set_value(self, select: str) -> None:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:SELect \n
		Snippet: driver.pulse.mop.plugin.variable.select.set_value(select = '1') \n
		Selects a plugin variable. \n
			:param select: string
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'PULSe:MOP:PLUGin:VARiable:SELect {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 10 total commands, 1 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._cmd_group)
		return self._time

	def get_auto(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:AUTO \n
		Snippet: value: float = driver.scenario.cemit.marker.get_auto() \n
		Enables the marker for restart. \n
			:return: auto: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:AUTO?')
		return Conversions.str_to_float(response)

	def set_auto(self, auto: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:AUTO \n
		Snippet: driver.scenario.cemit.marker.set_auto(auto = 1.0) \n
		Enables the marker for restart. \n
			:param auto: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(auto)
		self._core.io.write(f'SCENario:CEMit:MARKer:AUTO {param}')

	def get_fall(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:FALL \n
		Snippet: value: float = driver.scenario.cemit.marker.get_fall() \n
		Enables the marker for fall time. \n
			:return: fall: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:FALL?')
		return Conversions.str_to_float(response)

	def set_fall(self, fall: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:FALL \n
		Snippet: driver.scenario.cemit.marker.set_fall(fall = 1.0) \n
		Enables the marker for fall time. \n
			:param fall: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(fall)
		self._core.io.write(f'SCENario:CEMit:MARKer:FALL {param}')

	def get_force(self) -> bool:
		"""SCPI: SCENario:CEMit:MARKer:FORCe \n
		Snippet: value: bool = driver.scenario.cemit.marker.get_force() \n
		Determines how the marker is handled. \n
			:return: force: ON| OFF| 1| 0 ON | 1 Forces the selected marker type for every pulse of the selected emitter OFF | 0 Leaves the marker unchanged, as defined in the pulses and sequences of this emitter.
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:FORCe?')
		return Conversions.str_to_bool(response)

	def set_force(self, force: bool) -> None:
		"""SCPI: SCENario:CEMit:MARKer:FORCe \n
		Snippet: driver.scenario.cemit.marker.set_force(force = False) \n
		Determines how the marker is handled. \n
			:param force: ON| OFF| 1| 0 ON | 1 Forces the selected marker type for every pulse of the selected emitter OFF | 0 Leaves the marker unchanged, as defined in the pulses and sequences of this emitter.
		"""
		param = Conversions.bool_to_str(force)
		self._core.io.write(f'SCENario:CEMit:MARKer:FORCe {param}')

	def get_gate(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:GATE \n
		Snippet: value: float = driver.scenario.cemit.marker.get_gate() \n
		Enables marker for gate. \n
			:return: gate: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:GATE?')
		return Conversions.str_to_float(response)

	def set_gate(self, gate: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:GATE \n
		Snippet: driver.scenario.cemit.marker.set_gate(gate = 1.0) \n
		Enables marker for gate. \n
			:param gate: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(gate)
		self._core.io.write(f'SCENario:CEMit:MARKer:GATE {param}')

	def get_post(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:POST \n
		Snippet: value: float = driver.scenario.cemit.marker.get_post() \n
		Enables marker for post time. \n
			:return: post: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:POST?')
		return Conversions.str_to_float(response)

	def set_post(self, post: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:POST \n
		Snippet: driver.scenario.cemit.marker.set_post(post = 1.0) \n
		Enables marker for post time. \n
			:param post: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(post)
		self._core.io.write(f'SCENario:CEMit:MARKer:POST {param}')

	def get_pre(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:PRE \n
		Snippet: value: float = driver.scenario.cemit.marker.get_pre() \n
		Enables marker for pre time. \n
			:return: pre: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:PRE?')
		return Conversions.str_to_float(response)

	def set_pre(self, pre: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:PRE \n
		Snippet: driver.scenario.cemit.marker.set_pre(pre = 1.0) \n
		Enables marker for pre time. \n
			:param pre: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(pre)
		self._core.io.write(f'SCENario:CEMit:MARKer:PRE {param}')

	def get_rise(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:RISE \n
		Snippet: value: float = driver.scenario.cemit.marker.get_rise() \n
		Enables marker for rise time. \n
			:return: rise: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:RISE?')
		return Conversions.str_to_float(response)

	def set_rise(self, rise: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:RISE \n
		Snippet: driver.scenario.cemit.marker.set_rise(rise = 1.0) \n
		Enables marker for rise time. \n
			:param rise: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(rise)
		self._core.io.write(f'SCENario:CEMit:MARKer:RISE {param}')

	def get_width(self) -> float:
		"""SCPI: SCENario:CEMit:MARKer:WIDTh \n
		Snippet: value: float = driver.scenario.cemit.marker.get_width() \n
		Sets marker for the pulse width. \n
			:return: width: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		response = self._core.io.query_str('SCENario:CEMit:MARKer:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: SCENario:CEMit:MARKer:WIDTh \n
		Snippet: driver.scenario.cemit.marker.set_width(width = 1.0) \n
		Sets marker for the pulse width. \n
			:param width: float Binary value, where: M1 = 1 M1 = 2 M1 = 4 M1 = 8 Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'SCENario:CEMit:MARKer:WIDTh {param}')

	def clone(self) -> 'Marker':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Marker(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Level:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def get_reference(self) -> float:
		"""SCPI: WAVeform:LEVel:REFerence \n
		Snippet: value: float = driver.waveform.level.get_reference() \n
		Queries the reference level. \n
			:return: reference: float Range: 0 to 100
		"""
		response = self._core.io.query_str('WAVeform:LEVel:REFerence?')
		return Conversions.str_to_float(response)

	def set_reference(self, reference: float) -> None:
		"""SCPI: WAVeform:LEVel:REFerence \n
		Snippet: driver.waveform.level.set_reference(reference = 1.0) \n
		Queries the reference level. \n
			:param reference: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(reference)
		self._core.io.write(f'WAVeform:LEVel:REFerence {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Deployed:
	"""Deployed commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("deployed", core, parent)

	def get_name(self) -> str:
		"""SCPI: CPANel:SCENario:DEPLoyed:NAME \n
		Snippet: value: str = driver.cpanel.scenario.deployed.get_name() \n
		Queries the name of the current/last deployed scenario. \n
			:return: name: string
		"""
		response = self._core.io.query_str('CPANel:SCENario:DEPLoyed:NAME?')
		return trim_str_response(response)

	def get_time(self) -> str:
		"""SCPI: CPANel:SCENario:DEPLoyed:TIME \n
		Snippet: value: str = driver.cpanel.scenario.deployed.get_time() \n
		Queries the date and time the scenario has been deployed. \n
			:return: time: DD MMM YYY hh:mm:ss
		"""
		response = self._core.io.query_str('CPANel:SCENario:DEPLoyed:TIME?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	def clear(self) -> None:
		"""SCPI: SCENario:GENerator:CLEar \n
		Snippet: driver.scenario.generator.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SCENario:GENerator:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:GENerator:CLEar \n
		Snippet: driver.scenario.generator.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:GENerator:CLEar', opc_timeout_ms)

	def get_path(self) -> float:
		"""SCPI: SCENario:GENerator:PATH \n
		Snippet: value: float = driver.scenario.generator.get_path() \n
		Selects the signal path that will play the generated signal. \n
			:return: path: float Range: 1 to 32
		"""
		response = self._core.io.query_str('SCENario:GENerator:PATH?')
		return Conversions.str_to_float(response)

	def set_path(self, path: float) -> None:
		"""SCPI: SCENario:GENerator:PATH \n
		Snippet: driver.scenario.generator.set_path(path = 1.0) \n
		Selects the signal path that will play the generated signal. \n
			:param path: float Range: 1 to 32
		"""
		param = Conversions.decimal_value_to_str(path)
		self._core.io.write(f'SCENario:GENerator:PATH {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:GENerator \n
		Snippet: value: str = driver.scenario.generator.get_value() \n
		Sets the signal generator. \n
			:return: generator: string Use the command GENerator:CATalog? to query a list of configured generator.
		"""
		response = self._core.io.query_str('SCENario:GENerator?')
		return trim_str_response(response)

	def set_value(self, generator: str) -> None:
		"""SCPI: SCENario:GENerator \n
		Snippet: driver.scenario.generator.set_value(generator = '1') \n
		Sets the signal generator. \n
			:param generator: string Use the command GENerator:CATalog? to query a list of configured generator.
		"""
		param = Conversions.value_to_quoted_str(generator)
		self._core.io.write(f'SCENario:GENerator {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Module:
	"""Module commands group definition. 6 total commands, 0 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("module", core, parent)

	def get_author(self) -> str:
		"""SCPI: PLUGin:MODule:AUTHor \n
		Snippet: value: str = driver.plugin.module.get_author() \n
		Queries information on the loaded file. The query returns information as specified in the description of the
		corresponding function in 'Plug-in programming API'. The following are the possible values for the type query. \n
			:return: author: REPort| IPM | MOP MOP Plugin for IPM Plugin for REPort Plugin for reports created during the waveform generation
		"""
		response = self._core.io.query_str('PLUGin:MODule:AUTHor?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: PLUGin:MODule:COMMent \n
		Snippet: value: str = driver.plugin.module.get_comment() \n
		Queries information on the loaded file. The query returns information as specified in the description of the
		corresponding function in 'Plug-in programming API'. The following are the possible values for the type query. \n
			:return: comment: REPort| IPM | MOP MOP Plugin for IPM Plugin for REPort Plugin for reports created during the waveform generation
		"""
		response = self._core.io.query_str('PLUGin:MODule:COMMent?')
		return trim_str_response(response)

	def get_data(self) -> float:
		"""SCPI: PLUGin:MODule:DATA \n
		Snippet: value: float = driver.plugin.module.get_data() \n
		Queries whether the plugin requires data from a data source. \n
			:return: data: 0 | 1 0 Data source is not required 1 Data source is required
		"""
		response = self._core.io.query_str('PLUGin:MODule:DATA?')
		return Conversions.str_to_float(response)

	def get_name(self) -> str:
		"""SCPI: PLUGin:MODule:NAME \n
		Snippet: value: str = driver.plugin.module.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('PLUGin:MODule:NAME?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.ModuleType:
		"""SCPI: PLUGin:MODule:TYPE \n
		Snippet: value: enums.ModuleType = driver.plugin.module.get_type_py() \n
		Queries information on the loaded file. The query returns information as specified in the description of the
		corresponding function in 'Plug-in programming API'. The following are the possible values for the type query. \n
			:return: type_py: REPort| IPM | MOP MOP Plugin for IPM Plugin for REPort Plugin for reports created during the waveform generation
		"""
		response = self._core.io.query_str('PLUGin:MODule:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ModuleType)

	def get_version(self) -> str:
		"""SCPI: PLUGin:MODule:VERSion \n
		Snippet: value: str = driver.plugin.module.get_version() \n
		Queries information on the loaded file. The query returns information as specified in the description of the
		corresponding function in 'Plug-in programming API'. The following are the possible values for the type query. \n
			:return: version: REPort| IPM | MOP MOP Plugin for IPM Plugin for REPort Plugin for reports created during the waveform generation
		"""
		response = self._core.io.query_str('PLUGin:MODule:VERSion?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Lfm:
	"""Lfm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lfm", core, parent)

	def get_rate(self) -> float:
		"""SCPI: IMPort:PDW:DATA:LFM:RATE \n
		Snippet: value: float = driver.importPy.pdw.data.lfm.get_rate() \n
		Queries the pulse parameter. \n
			:return: rate: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:LFM:RATE?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def get_post(self) -> float:
		"""SCPI: SCENario:DF:MARKer:TIME:POST \n
		Snippet: value: float = driver.scenario.df.marker.time.get_post() \n
		Specifies post marker time. \n
			:return: post: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('SCENario:DF:MARKer:TIME:POST?')
		return Conversions.str_to_float(response)

	def set_post(self, post: float) -> None:
		"""SCPI: SCENario:DF:MARKer:TIME:POST \n
		Snippet: driver.scenario.df.marker.time.set_post(post = 1.0) \n
		Specifies post marker time. \n
			:param post: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(post)
		self._core.io.write(f'SCENario:DF:MARKer:TIME:POST {param}')

	def get_pre(self) -> float:
		"""SCPI: SCENario:DF:MARKer:TIME:PRE \n
		Snippet: value: float = driver.scenario.df.marker.time.get_pre() \n
		Specifies pre marker time. \n
			:return: pre: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('SCENario:DF:MARKer:TIME:PRE?')
		return Conversions.str_to_float(response)

	def set_pre(self, pre: float) -> None:
		"""SCPI: SCENario:DF:MARKer:TIME:PRE \n
		Snippet: driver.scenario.df.marker.time.set_pre(pre = 1.0) \n
		Specifies pre marker time. \n
			:param pre: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(pre)
		self._core.io.write(f'SCENario:DF:MARKer:TIME:PRE {param}')



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setup:
	"""Setup commands group definition. 16 total commands, 4 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setup", core, parent)

	@property
	def higHq(self):
		"""higHq commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_higHq'):
			from .HigHq import HigHq
			self._higHq = HigHq(self._core, self._cmd_group)
		return self._higHq

	@property
	def locpl(self):
		"""locpl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_locpl'):
			from .Locpl import Locpl
			self._locpl = Locpl(self._core, self._cmd_group)
		return self._locpl

	@property
	def pmod(self):
		"""pmod commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_pmod'):
			from .Pmod import Pmod
			self._pmod = Pmod(self._core, self._cmd_group)
		return self._pmod

	@property
	def rfAlign(self):
		"""rfAlign commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_rfAlign'):
			from .RfAlign import RfAlign
			self._rfAlign = RfAlign(self._core, self._cmd_group)
		return self._rfAlign

	def set_add(self, add: str) -> None:
		"""SCPI: SETup:ADD \n
		Snippet: driver.setup.set_add(add = '1') \n
		Appends new item. \n
			:param add: No help available
		"""
		param = Conversions.value_to_quoted_str(add)
		self._core.io.write(f'SETup:ADD {param}')

	# noinspection PyTypeChecker
	def get_bb_sync(self) -> enums.BbSync:
		"""SCPI: SETup:BBSYnc \n
		Snippet: value: enums.BbSync = driver.setup.get_bb_sync() \n
		Sets if and which method the signal generator uses to synchronize the signals in the baseband domain.
		Relevant in multi-instrument setups where the signals of the different emitters are generated in different paths and
		different signal generators. \n
			:return: bb_sync: UNSYnc| TRIGger| CTRigger UNSYnc Unsynchronized baseband generators TRIGger Synchronized setup, where the instruments are connected in a primary/secondary chain. General-purpose trigger signal is used. CTRigger Synchronized primary/secondary setup, that uses a dedicated common trigger signal.
		"""
		response = self._core.io.query_str('SETup:BBSYnc?')
		return Conversions.str_to_scalar_enum(response, enums.BbSync)

	def set_bb_sync(self, bb_sync: enums.BbSync) -> None:
		"""SCPI: SETup:BBSYnc \n
		Snippet: driver.setup.set_bb_sync(bb_sync = enums.BbSync.CTRigger) \n
		Sets if and which method the signal generator uses to synchronize the signals in the baseband domain.
		Relevant in multi-instrument setups where the signals of the different emitters are generated in different paths and
		different signal generators. \n
			:param bb_sync: UNSYnc| TRIGger| CTRigger UNSYnc Unsynchronized baseband generators TRIGger Synchronized setup, where the instruments are connected in a primary/secondary chain. General-purpose trigger signal is used. CTRigger Synchronized primary/secondary setup, that uses a dedicated common trigger signal.
		"""
		param = Conversions.enum_scalar_to_str(bb_sync, enums.BbSync)
		self._core.io.write(f'SETup:BBSYnc {param}')

	def get_count(self) -> float:
		"""SCPI: SETup:COUNt \n
		Snippet: value: float = driver.setup.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SETup:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SETup:DELete \n
		Snippet: driver.setup.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SETup:DELete {param}')

	def export(self, export: str) -> None:
		"""SCPI: SETup:EXPort \n
		Snippet: driver.setup.export(export = '1') \n
		Save current setup in a file. \n
			:param export: Complete path, incl filename and file extension *.ps_hwsetup
		"""
		param = Conversions.value_to_quoted_str(export)
		self._core.io.write(f'SETup:EXPort {param}')

	def set_import_py(self, import_py: str) -> None:
		"""SCPI: SETup:IMPort \n
		Snippet: driver.setup.set_import_py(import_py = '1') \n
		Loads the selected setup file. Imported setups are appended in the list of setups. \n
			:param import_py: Complete path, incl filename and file extension *.ps_hwsetup
		"""
		param = Conversions.value_to_quoted_str(import_py)
		self._core.io.write(f'SETup:IMPort {param}')

	def get_list_py(self) -> List[int]:
		"""SCPI: SETup:LIST \n
		Snippet: value: List[int] = driver.setup.get_list_py() \n
		Queries the name of the available hardware setups. \n
			:return: list_py: 'Setup#1','Setup#2',...
		"""
		response = self._core.io.query_bin_or_ascii_int_list('SETup:LIST?')
		return response

	def get_select(self) -> str:
		"""SCPI: SETup:SELect \n
		Snippet: value: str = driver.setup.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SETup:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: SETup:SELect \n
		Snippet: driver.setup.set_select(select = '1') \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'SETup:SELect {param}')

	def clone(self) -> 'Setup':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Setup(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ipm:
	"""Ipm commands group definition. 14 total commands, 4 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ipm", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	@property
	def random(self):
		"""random commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_random'):
			from .Random import Random
			self._random = Random(self._core, self._cmd_group)
		return self._random

	@property
	def source(self):
		"""source commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_source'):
			from .Source import Source
			self._source = Source(self._core, self._cmd_group)
		return self._source

	@property
	def target(self):
		"""target commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_target'):
			from .Target import Target
			self._target = Target(self._core, self._cmd_group)
		return self._target

	def get_count(self) -> float:
		"""SCPI: SEQuence:ITEM:IPM:COUNt \n
		Snippet: value: float = driver.sequence.item.ipm.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SEQuence:ITEM:IPM:DELete \n
		Snippet: driver.sequence.item.ipm.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SEQuence:ITEM:IPM:DELete {param}')

	def get_equation(self) -> str:
		"""SCPI: SEQuence:ITEM:IPM:EQUation \n
		Snippet: value: str = driver.sequence.item.ipm.get_equation() \n
		Defines output value of the IPM mathematically. \n
			:return: equation: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:EQUation?')
		return trim_str_response(response)

	def set_equation(self, equation: str) -> None:
		"""SCPI: SEQuence:ITEM:IPM:EQUation \n
		Snippet: driver.sequence.item.ipm.set_equation(equation = '1') \n
		Defines output value of the IPM mathematically. \n
			:param equation: string
		"""
		param = Conversions.value_to_quoted_str(equation)
		self._core.io.write(f'SEQuence:ITEM:IPM:EQUation {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.IpmMode:
		"""SCPI: SEQuence:ITEM:IPM:MODE \n
		Snippet: value: enums.IpmMode = driver.sequence.item.ipm.get_mode() \n
		Defines the way the variations are applied on repeating pulses. \n
			:return: mode: INDividual| SAME
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.IpmMode)

	def set_mode(self, mode: enums.IpmMode) -> None:
		"""SCPI: SEQuence:ITEM:IPM:MODE \n
		Snippet: driver.sequence.item.ipm.set_mode(mode = enums.IpmMode.INDividual) \n
		Defines the way the variations are applied on repeating pulses. \n
			:param mode: INDividual| SAME
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.IpmMode)
		self._core.io.write(f'SEQuence:ITEM:IPM:MODE {param}')

	def get_restart(self) -> bool:
		"""SCPI: SEQuence:ITEM:IPM:RESTart \n
		Snippet: value: bool = driver.sequence.item.ipm.get_restart() \n
		Restarts the IPM for this sequence line item. \n
			:return: restart: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:RESTart?')
		return Conversions.str_to_bool(response)

	def set_restart(self, restart: bool) -> None:
		"""SCPI: SEQuence:ITEM:IPM:RESTart \n
		Snippet: driver.sequence.item.ipm.set_restart(restart = False) \n
		Restarts the IPM for this sequence line item. \n
			:param restart: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(restart)
		self._core.io.write(f'SEQuence:ITEM:IPM:RESTart {param}')

	def get_select(self) -> float:
		"""SCPI: SEQuence:ITEM:IPM:SELect \n
		Snippet: value: float = driver.sequence.item.ipm.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SEQuence:ITEM:IPM:SELect \n
		Snippet: driver.sequence.item.ipm.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SEQuence:ITEM:IPM:SELect {param}')

	def clone(self) -> 'Ipm':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ipm(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImportPy:
	"""ImportPy commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("importPy", core, parent)

	@property
	def exec(self):
		"""exec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_exec'):
			from .Exec import Exec
			self._exec = Exec(self._core, self._cmd_group)
		return self._exec

	def get_file(self) -> str:
		"""SCPI: SCAN:CUSTom:IMPort:FILE \n
		Snippet: value: str = driver.scan.custom.importPy.get_file() \n
		Sets the file to import. \n
			:return: file: string
		"""
		response = self._core.io.query_str('SCAN:CUSTom:IMPort:FILE?')
		return trim_str_response(response)

	def set_file(self, file: str) -> None:
		"""SCPI: SCAN:CUSTom:IMPort:FILE \n
		Snippet: driver.scan.custom.importPy.set_file(file = '1') \n
		Sets the file to import. \n
			:param file: string
		"""
		param = Conversions.value_to_quoted_str(file)
		self._core.io.write(f'SCAN:CUSTom:IMPort:FILE {param}')

	def clone(self) -> 'ImportPy':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ImportPy(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Clock:
	"""Clock commands group definition. 4 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clock", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import Auto
			self._auto = Auto(self._core, self._cmd_group)
		return self._auto

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AutoManualMode:
		"""SCPI: SCENario:OUTPut:CLOCk:MODE \n
		Snippet: value: enums.AutoManualMode = driver.scenario.output.clock.get_mode() \n
		Sets the clock mode. \n
			:return: mode: AUTO| MANual AUTO Clock rate is retrieved from the generated waveform. MANual Clock rate is user-defined
		"""
		response = self._core.io.query_str('SCENario:OUTPut:CLOCk:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_mode(self, mode: enums.AutoManualMode) -> None:
		"""SCPI: SCENario:OUTPut:CLOCk:MODE \n
		Snippet: driver.scenario.output.clock.set_mode(mode = enums.AutoManualMode.AUTO) \n
		Sets the clock mode. \n
			:param mode: AUTO| MANual AUTO Clock rate is retrieved from the generated waveform. MANual Clock rate is user-defined
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
		self._core.io.write(f'SCENario:OUTPut:CLOCk:MODE {param}')

	def get_user(self) -> float:
		"""SCPI: SCENario:OUTPut:CLOCk:USER \n
		Snippet: value: float = driver.scenario.output.clock.get_user() \n
		Sets a user defined clock rate. \n
			:return: user: float Range: 1 to 2.4e+09
		"""
		response = self._core.io.query_str('SCENario:OUTPut:CLOCk:USER?')
		return Conversions.str_to_float(response)

	def set_user(self, user: float) -> None:
		"""SCPI: SCENario:OUTPut:CLOCk:USER \n
		Snippet: driver.scenario.output.clock.set_user(user = 1.0) \n
		Sets a user defined clock rate. \n
			:param user: float Range: 1 to 2.4e+09
		"""
		param = Conversions.decimal_value_to_str(user)
		self._core.io.write(f'SCENario:OUTPut:CLOCk:USER {param}')

	def clone(self) -> 'Clock':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Clock(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Emitters:
	"""Emitters commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emitters", core, parent)

	def get_list_py(self) -> str:
		"""SCPI: ASSignment:EMITters:LIST \n
		Snippet: value: str = driver.assignment.emitters.get_list_py() \n
		Queries the alias names of the unassigned emitters/interferers. \n
			:return: list_py: 'Emitter/Inter#1','Emitter/Inter#2',...
		"""
		response = self._core.io.query_str('ASSignment:EMITters:LIST?')
		return trim_str_response(response)

	def get_select(self) -> str:
		"""SCPI: ASSignment:EMITters:SELect \n
		Snippet: value: str = driver.assignment.emitters.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('ASSignment:EMITters:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: ASSignment:EMITters:SELect \n
		Snippet: driver.assignment.emitters.set_select(select = '1') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'ASSignment:EMITters:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Show:
	"""Show commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("show", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: PROGram:TUTorials:SHOW:ENABle \n
		Snippet: value: bool = driver.program.tutorials.show.get_enable() \n
		This setting re-enables all tutorials. Tutorials are shown upon opening certain dialogs for the first time (e.g. 2D Map) .
		When the tutorial has been viewed, it is then disabled. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PROGram:TUTorials:SHOW:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: PROGram:TUTorials:SHOW:ENABle \n
		Snippet: driver.program.tutorials.show.set_enable(enable = False) \n
		This setting re-enables all tutorials. Tutorials are shown upon opening certain dialogs for the first time (e.g. 2D Map) .
		When the tutorial has been viewed, it is then disabled. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'PROGram:TUTorials:SHOW:ENABle {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rep:
	"""Rep commands group definition. 7 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rep", core, parent)

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_count'):
			from .Count import Count
			self._count = Count(self._core, self._cmd_group)
		return self._count

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.RepetitionType:
		"""SCPI: SEQuence:ITEM:REP:TYPE \n
		Snippet: value: enums.RepetitionType = driver.sequence.item.rep.get_type_py() \n
		Sets how the repetition number is defined. \n
			:return: type_py: FIXed| VARiable| DURation
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.RepetitionType)

	def set_type_py(self, type_py: enums.RepetitionType) -> None:
		"""SCPI: SEQuence:ITEM:REP:TYPE \n
		Snippet: driver.sequence.item.rep.set_type_py(type_py = enums.RepetitionType.DURation) \n
		Sets how the repetition number is defined. \n
			:param type_py: FIXed| VARiable| DURation
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.RepetitionType)
		self._core.io.write(f'SEQuence:ITEM:REP:TYPE {param}')

	def get_variable(self) -> str:
		"""SCPI: SEQuence:ITEM:REP:VARiable \n
		Snippet: value: str = driver.sequence.item.rep.get_variable() \n
		Seta a repetition variable. \n
			:return: variable: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:VARiable?')
		return trim_str_response(response)

	def set_variable(self, variable: str) -> None:
		"""SCPI: SEQuence:ITEM:REP:VARiable \n
		Snippet: driver.sequence.item.rep.set_variable(variable = '1') \n
		Seta a repetition variable. \n
			:param variable: string
		"""
		param = Conversions.value_to_quoted_str(variable)
		self._core.io.write(f'SEQuence:ITEM:REP:VARiable {param}')

	def clone(self) -> 'Rep':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rep(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scan:
	"""Scan commands group definition. 89 total commands, 10 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scan", core, parent)

	@property
	def circular(self):
		"""circular commands group. 0 Sub-classes, 10 commands."""
		if not hasattr(self, '_circular'):
			from .Circular import Circular
			self._circular = Circular(self._core, self._cmd_group)
		return self._circular

	@property
	def conical(self):
		"""conical commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_conical'):
			from .Conical import Conical
			self._conical = Conical(self._core, self._cmd_group)
		return self._conical

	@property
	def custom(self):
		"""custom commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_custom'):
			from .Custom import Custom
			self._custom = Custom(self._core, self._cmd_group)
		return self._custom

	@property
	def helical(self):
		"""helical commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_helical'):
			from .Helical import Helical
			self._helical = Helical(self._core, self._cmd_group)
		return self._helical

	@property
	def lissajous(self):
		"""lissajous commands group. 0 Sub-classes, 7 commands."""
		if not hasattr(self, '_lissajous'):
			from .Lissajous import Lissajous
			self._lissajous = Lissajous(self._core, self._cmd_group)
		return self._lissajous

	@property
	def lsw(self):
		"""lsw commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_lsw'):
			from .Lsw import Lsw
			self._lsw = Lsw(self._core, self._cmd_group)
		return self._lsw

	@property
	def raster(self):
		"""raster commands group. 0 Sub-classes, 13 commands."""
		if not hasattr(self, '_raster'):
			from .Raster import Raster
			self._raster = Raster(self._core, self._cmd_group)
		return self._raster

	@property
	def sector(self):
		"""sector commands group. 0 Sub-classes, 10 commands."""
		if not hasattr(self, '_sector'):
			from .Sector import Sector
			self._sector = Sector(self._core, self._cmd_group)
		return self._sector

	@property
	def sin(self):
		"""sin commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_sin'):
			from .Sin import Sin
			self._sin = Sin(self._core, self._cmd_group)
		return self._sin

	@property
	def spiral(self):
		"""spiral commands group. 0 Sub-classes, 9 commands."""
		if not hasattr(self, '_spiral'):
			from .Spiral import Spiral
			self._spiral = Spiral(self._core, self._cmd_group)
		return self._spiral

	def get_catalog(self) -> str:
		"""SCPI: SCAN:CATalog \n
		Snippet: value: str = driver.scan.get_catalog() \n
		Queries the available repository elements in the database. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SCAN:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: SCAN:COMMent \n
		Snippet: value: str = driver.scan.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('SCAN:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: SCAN:COMMent \n
		Snippet: driver.scan.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'SCAN:COMMent {param}')

	def set_create(self, create: str) -> None:
		"""SCPI: SCAN:CREate \n
		Snippet: driver.scan.set_create(create = '1') \n
		Creates a repository element with the selected name. \n
			:param create: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(create)
		self._core.io.write(f'SCAN:CREate {param}')

	def get_name(self) -> str:
		"""SCPI: SCAN:NAME \n
		Snippet: value: str = driver.scan.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('SCAN:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: SCAN:NAME \n
		Snippet: driver.scan.set_name(name = '1') \n
		Renames the selected repository element. \n
			:param name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'SCAN:NAME {param}')

	def set_remove(self, remove: str) -> None:
		"""SCPI: SCAN:REMove \n
		Snippet: driver.scan.set_remove(remove = '1') \n
		Removes the selected element from the workspace. The element must not reference any child elements. Remove the referenced
		elements first. \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'SCAN:REMove {param}')

	def get_select(self) -> str:
		"""SCPI: SCAN:SELect \n
		Snippet: value: str = driver.scan.get_select() \n
		Selects the repository element to which the subsequent commands apply. \n
			:return: select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		response = self._core.io.query_str('SCAN:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: SCAN:SELect \n
		Snippet: driver.scan.set_select(select = '1') \n
		Selects the repository element to which the subsequent commands apply. \n
			:param select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'SCAN:SELect {param}')

	def get_steering(self) -> bool:
		"""SCPI: SCAN:STEering \n
		Snippet: value: bool = driver.scan.get_steering() \n
		Defines whether electronic steering is used. Electronic steering is only available for scan types that use phased array
		antennas. \n
			:return: steering: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:STEering?')
		return Conversions.str_to_bool(response)

	def set_steering(self, steering: bool) -> None:
		"""SCPI: SCAN:STEering \n
		Snippet: driver.scan.set_steering(steering = False) \n
		Defines whether electronic steering is used. Electronic steering is only available for scan types that use phased array
		antennas. \n
			:param steering: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(steering)
		self._core.io.write(f'SCAN:STEering {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.ScanType:
		"""SCPI: SCAN:TYPE \n
		Snippet: value: enums.ScanType = driver.scan.get_type_py() \n
		Sets the scan type. \n
			:return: type_py: CIRCular| SECTor| RASTer| CONical| HELical| SPIRal| LSW| SIN| CUSTom| LISSajous
		"""
		response = self._core.io.query_str('SCAN:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ScanType)

	def set_type_py(self, type_py: enums.ScanType) -> None:
		"""SCPI: SCAN:TYPE \n
		Snippet: driver.scan.set_type_py(type_py = enums.ScanType.CIRCular) \n
		Sets the scan type. \n
			:param type_py: CIRCular| SECTor| RASTer| CONical| HELical| SPIRal| LSW| SIN| CUSTom| LISSajous
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.ScanType)
		self._core.io.write(f'SCAN:TYPE {param}')

	def clone(self) -> 'Scan':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scan(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPy:
	"""ListPy commands group definition. 13 total commands, 2 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	@property
	def firing(self):
		"""firing commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_firing'):
			from .Firing import Firing
			self._firing = Firing(self._core, self._cmd_group)
		return self._firing

	@property
	def item(self):
		"""item commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_item'):
			from .Item import Item
			self._item = Item(self._core, self._cmd_group)
		return self._item

	# noinspection PyTypeChecker
	def get_base(self) -> enums.BaseDomain:
		"""SCPI: IPM:LIST:BASE \n
		Snippet: value: enums.BaseDomain = driver.ipm.listPy.get_base() \n
		Sets the IPM profile base and defines how the steps repetition is defined. \n
			:return: base: PULSe| TIME PULSe Steps are repeated several times, as set with the command method RsPulseSeq.Ipm.ListPy.Item.repetition. TIME Steps are repeated for the defined time duration, as set with the command method RsPulseSeq.Ipm.ListPy.Item.time.
		"""
		response = self._core.io.query_str('IPM:LIST:BASE?')
		return Conversions.str_to_scalar_enum(response, enums.BaseDomain)

	def set_base(self, base: enums.BaseDomain) -> None:
		"""SCPI: IPM:LIST:BASE \n
		Snippet: driver.ipm.listPy.set_base(base = enums.BaseDomain.PULSe) \n
		Sets the IPM profile base and defines how the steps repetition is defined. \n
			:param base: PULSe| TIME PULSe Steps are repeated several times, as set with the command method RsPulseSeq.Ipm.ListPy.Item.repetition. TIME Steps are repeated for the defined time duration, as set with the command method RsPulseSeq.Ipm.ListPy.Item.time.
		"""
		param = Conversions.enum_scalar_to_str(base, enums.BaseDomain)
		self._core.io.write(f'IPM:LIST:BASE {param}')

	def clear(self) -> None:
		"""SCPI: IPM:LIST:CLEar \n
		Snippet: driver.ipm.listPy.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'IPM:LIST:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: IPM:LIST:CLEar \n
		Snippet: driver.ipm.listPy.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'IPM:LIST:CLEar', opc_timeout_ms)

	def get_load(self) -> str:
		"""SCPI: IPM:LIST:LOAD \n
		Snippet: value: str = driver.ipm.listPy.get_load() \n
		Loads an IPM profile form an ASCII file. \n
			:return: load: string File path, file name, and file extension
		"""
		response = self._core.io.query_str('IPM:LIST:LOAD?')
		return trim_str_response(response)

	def set_load(self, load: str) -> None:
		"""SCPI: IPM:LIST:LOAD \n
		Snippet: driver.ipm.listPy.set_load(load = '1') \n
		Loads an IPM profile form an ASCII file. \n
			:param load: string File path, file name, and file extension
		"""
		param = Conversions.value_to_quoted_str(load)
		self._core.io.write(f'IPM:LIST:LOAD {param}')

	def get_save(self) -> str:
		"""SCPI: IPM:LIST:SAVE \n
		Snippet: value: str = driver.ipm.listPy.get_save() \n
		Stores the IPM profile as a file. \n
			:return: save: string File path incl. file name and extension.
		"""
		response = self._core.io.query_str('IPM:LIST:SAVE?')
		return trim_str_response(response)

	def set_save(self, save: str) -> None:
		"""SCPI: IPM:LIST:SAVE \n
		Snippet: driver.ipm.listPy.set_save(save = '1') \n
		Stores the IPM profile as a file. \n
			:param save: string File path incl. file name and extension.
		"""
		param = Conversions.value_to_quoted_str(save)
		self._core.io.write(f'IPM:LIST:SAVE {param}')

	def clone(self) -> 'ListPy':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ListPy(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Log:
	"""Log commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("log", core, parent)

	def set_min(self, min_py: float) -> None:
		"""SCPI: PLOT:POLar:LOG:MIN \n
		Snippet: driver.plot.polar.log.set_min(min_py = 1.0) \n
		Sets the minimum value displayed on the y axis. \n
			:param min_py: float
		"""
		param = Conversions.decimal_value_to_str(min_py)
		self._core.io.write(f'PLOT:POLar:LOG:MIN {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Count:
	"""Count commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get_duration(self) -> float:
		"""SCPI: SEQuence:ITEM:REP:COUNt:DURation \n
		Snippet: value: float = driver.sequence.item.rep.count.get_duration() \n
		Sets a time duration. \n
			:return: duration: float Range: 0 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:COUNt:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: SEQuence:ITEM:REP:COUNt:DURation \n
		Snippet: driver.sequence.item.rep.count.set_duration(duration = 1.0) \n
		Sets a time duration. \n
			:param duration: float Range: 0 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SEQuence:ITEM:REP:COUNt:DURation {param}')

	def get_fixed(self) -> float:
		"""SCPI: SEQuence:ITEM:REP:COUNt:FIXed \n
		Snippet: value: float = driver.sequence.item.rep.count.get_fixed() \n
		Sets the repetition number as a numeric value. \n
			:return: fixed: float Range: 1 to 65535
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:COUNt:FIXed?')
		return Conversions.str_to_float(response)

	def set_fixed(self, fixed: float) -> None:
		"""SCPI: SEQuence:ITEM:REP:COUNt:FIXed \n
		Snippet: driver.sequence.item.rep.count.set_fixed(fixed = 1.0) \n
		Sets the repetition number as a numeric value. \n
			:param fixed: float Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(fixed)
		self._core.io.write(f'SEQuence:ITEM:REP:COUNt:FIXed {param}')

	def get_maximum(self) -> float:
		"""SCPI: SEQuence:ITEM:REP:COUNt:MAXimum \n
		Snippet: value: float = driver.sequence.item.rep.count.get_maximum() \n
		Sets the value range of the repetition count. \n
			:return: maximum: float Range: 1 to 65535
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:COUNt:MAXimum?')
		return Conversions.str_to_float(response)

	def set_maximum(self, maximum: float) -> None:
		"""SCPI: SEQuence:ITEM:REP:COUNt:MAXimum \n
		Snippet: driver.sequence.item.rep.count.set_maximum(maximum = 1.0) \n
		Sets the value range of the repetition count. \n
			:param maximum: float Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(maximum)
		self._core.io.write(f'SEQuence:ITEM:REP:COUNt:MAXimum {param}')

	def get_minimum(self) -> float:
		"""SCPI: SEQuence:ITEM:REP:COUNt:MINimum \n
		Snippet: value: float = driver.sequence.item.rep.count.get_minimum() \n
		Sets the value range of the repetition count. \n
			:return: minimum: No help available
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:COUNt:MINimum?')
		return Conversions.str_to_float(response)

	def set_minimum(self, minimum: float) -> None:
		"""SCPI: SEQuence:ITEM:REP:COUNt:MINimum \n
		Snippet: driver.sequence.item.rep.count.set_minimum(minimum = 1.0) \n
		Sets the value range of the repetition count. \n
			:param minimum: float Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(minimum)
		self._core.io.write(f'SEQuence:ITEM:REP:COUNt:MINimum {param}')

	def get_step(self) -> float:
		"""SCPI: SEQuence:ITEM:REP:COUNt:STEP \n
		Snippet: value: float = driver.sequence.item.rep.count.get_step() \n
		Sets the repetition count granularity. \n
			:return: step: float Range: 1 to 65535
		"""
		response = self._core.io.query_str('SEQuence:ITEM:REP:COUNt:STEP?')
		return Conversions.str_to_float(response)

	def set_step(self, step: float) -> None:
		"""SCPI: SEQuence:ITEM:REP:COUNt:STEP \n
		Snippet: driver.sequence.item.rep.count.set_step(step = 1.0) \n
		Sets the repetition count granularity. \n
			:param step: float Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'SEQuence:ITEM:REP:COUNt:STEP {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 11 total commands, 1 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def item(self):
		"""item commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_item'):
			from .Item import Item
			self._item = Item(self._core, self._cmd_group)
		return self._item

	def clear(self) -> None:
		"""SCPI: PULSe:ENVelope:DATA:CLEar \n
		Snippet: driver.pulse.envelope.data.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'PULSe:ENVelope:DATA:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: PULSe:ENVelope:DATA:CLEar \n
		Snippet: driver.pulse.envelope.data.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'PULSe:ENVelope:DATA:CLEar', opc_timeout_ms)

	def get_load(self) -> str:
		"""SCPI: PULSe:ENVelope:DATA:LOAD \n
		Snippet: value: str = driver.pulse.envelope.data.get_load() \n
		Loads an envelope description form an ASCII file. \n
			:return: load: string File path, file name, and file extension
		"""
		response = self._core.io.query_str('PULSe:ENVelope:DATA:LOAD?')
		return trim_str_response(response)

	def set_load(self, load: str) -> None:
		"""SCPI: PULSe:ENVelope:DATA:LOAD \n
		Snippet: driver.pulse.envelope.data.set_load(load = '1') \n
		Loads an envelope description form an ASCII file. \n
			:param load: string File path, file name, and file extension
		"""
		param = Conversions.value_to_quoted_str(load)
		self._core.io.write(f'PULSe:ENVelope:DATA:LOAD {param}')

	def get_multiplier(self) -> float:
		"""SCPI: PULSe:ENVelope:DATA:MULTiplier \n
		Snippet: value: float = driver.pulse.envelope.data.get_multiplier() \n
		Sets a multiplier factor. \n
			:return: multiplier: float Range: -100 to 100
		"""
		response = self._core.io.query_str('PULSe:ENVelope:DATA:MULTiplier?')
		return Conversions.str_to_float(response)

	def set_multiplier(self, multiplier: float) -> None:
		"""SCPI: PULSe:ENVelope:DATA:MULTiplier \n
		Snippet: driver.pulse.envelope.data.set_multiplier(multiplier = 1.0) \n
		Sets a multiplier factor. \n
			:param multiplier: float Range: -100 to 100
		"""
		param = Conversions.decimal_value_to_str(multiplier)
		self._core.io.write(f'PULSe:ENVelope:DATA:MULTiplier {param}')

	def get_offset(self) -> float:
		"""SCPI: PULSe:ENVelope:DATA:OFFSet \n
		Snippet: value: float = driver.pulse.envelope.data.get_offset() \n
		Sets an offset for the envelope. \n
			:return: offset: float Range: -100 to 100
		"""
		response = self._core.io.query_str('PULSe:ENVelope:DATA:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: PULSe:ENVelope:DATA:OFFSet \n
		Snippet: driver.pulse.envelope.data.set_offset(offset = 1.0) \n
		Sets an offset for the envelope. \n
			:param offset: float Range: -100 to 100
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'PULSe:ENVelope:DATA:OFFSet {param}')

	def get_save(self) -> str:
		"""SCPI: PULSe:ENVelope:DATA:SAVE \n
		Snippet: value: str = driver.pulse.envelope.data.get_save() \n
		Stores the custom envelope into file. \n
			:return: save: string File path, file name, and file extension
		"""
		response = self._core.io.query_str('PULSe:ENVelope:DATA:SAVE?')
		return trim_str_response(response)

	def set_save(self, save: str) -> None:
		"""SCPI: PULSe:ENVelope:DATA:SAVE \n
		Snippet: driver.pulse.envelope.data.set_save(save = '1') \n
		Stores the custom envelope into file. \n
			:param save: string File path, file name, and file extension
		"""
		param = Conversions.value_to_quoted_str(save)
		self._core.io.write(f'PULSe:ENVelope:DATA:SAVE {param}')

	# noinspection PyTypeChecker
	def get_unit(self) -> enums.DataUnit:
		"""SCPI: PULSe:ENVelope:DATA:UNIT \n
		Snippet: value: enums.DataUnit = driver.pulse.envelope.data.get_unit() \n
		Sets the data format. \n
			:return: unit: VOLTage| WATTs| DB
		"""
		response = self._core.io.query_str('PULSe:ENVelope:DATA:UNIT?')
		return Conversions.str_to_scalar_enum(response, enums.DataUnit)

	def set_unit(self, unit: enums.DataUnit) -> None:
		"""SCPI: PULSe:ENVelope:DATA:UNIT \n
		Snippet: driver.pulse.envelope.data.set_unit(unit = enums.DataUnit.DB) \n
		Sets the data format. \n
			:param unit: VOLTage| WATTs| DB
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.DataUnit)
		self._core.io.write(f'PULSe:ENVelope:DATA:UNIT {param}')

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vfile:
	"""Vfile commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("vfile", core, parent)

	def clear(self) -> None:
		"""SCPI: SCENario:DF:MOVement:VFILe:CLEar \n
		Snippet: driver.scenario.df.movement.vfile.clear() \n
		Discards the selected vehicle description file. \n
		"""
		self._core.io.write(f'SCENario:DF:MOVement:VFILe:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:DF:MOVement:VFILe:CLEar \n
		Snippet: driver.scenario.df.movement.vfile.clear_with_opc() \n
		Discards the selected vehicle description file. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:DF:MOVement:VFILe:CLEar', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: SCENario:DF:MOVement:VFILe \n
		Snippet: value: str = driver.scenario.df.movement.vfile.get_value() \n
		Loads the selected vehicle description file (*.xvd) . To import and apply the files, send the command method RsPulseSeq.
		Scenario.Localized.Movement.ImportPy.set. \n
			:return: vfile: string Filename or complete file path, incl. file extension. Example files are provided with the software. For description, see 'Vehicle description files (Used for smoothening) '.
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:VFILe?')
		return trim_str_response(response)

	def set_value(self, vfile: str) -> None:
		"""SCPI: SCENario:DF:MOVement:VFILe \n
		Snippet: driver.scenario.df.movement.vfile.set_value(vfile = '1') \n
		Loads the selected vehicle description file (*.xvd) . To import and apply the files, send the command method RsPulseSeq.
		Scenario.Localized.Movement.ImportPy.set. \n
			:param vfile: string Filename or complete file path, incl. file extension. Example files are provided with the software. For description, see 'Vehicle description files (Used for smoothening) '.
		"""
		param = Conversions.value_to_quoted_str(vfile)
		self._core.io.write(f'SCENario:DF:MOVement:VFILe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HpBw:
	"""HpBw commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hpBw", core, parent)

	def get_azimuth(self) -> float:
		"""SCPI: ANTenna:MODel:SINC:HPBW:AZIMuth \n
		Snippet: value: float = driver.antenna.model.sinc.hpBw.get_azimuth() \n
		Sets the Half-Power Beam Width in azimuth and elevation direction for the Gaussian and Sin(x) /x antennas. \n
			:return: azimuth: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:SINC:HPBW:AZIMuth?')
		return Conversions.str_to_float(response)

	def set_azimuth(self, azimuth: float) -> None:
		"""SCPI: ANTenna:MODel:SINC:HPBW:AZIMuth \n
		Snippet: driver.antenna.model.sinc.hpBw.set_azimuth(azimuth = 1.0) \n
		Sets the Half-Power Beam Width in azimuth and elevation direction for the Gaussian and Sin(x) /x antennas. \n
			:param azimuth: float Range: 0.1 to 45, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(azimuth)
		self._core.io.write(f'ANTenna:MODel:SINC:HPBW:AZIMuth {param}')

	def get_elevation(self) -> float:
		"""SCPI: ANTenna:MODel:SINC:HPBW:ELEVation \n
		Snippet: value: float = driver.antenna.model.sinc.hpBw.get_elevation() \n
		Sets the Half-Power Beam Width in azimuth and elevation direction for the Gaussian and Sin(x) /x antennas. \n
			:return: elevation: float Range: 0.1 to 45, Unit: degree
		"""
		response = self._core.io.query_str('ANTenna:MODel:SINC:HPBW:ELEVation?')
		return Conversions.str_to_float(response)

	def set_elevation(self, elevation: float) -> None:
		"""SCPI: ANTenna:MODel:SINC:HPBW:ELEVation \n
		Snippet: driver.antenna.model.sinc.hpBw.set_elevation(elevation = 1.0) \n
		Sets the Half-Power Beam Width in azimuth and elevation direction for the Gaussian and Sin(x) /x antennas. \n
			:param elevation: float Range: 0.1 to 45, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(elevation)
		self._core.io.write(f'ANTenna:MODel:SINC:HPBW:ELEVation {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmMos:
	"""AmMos commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("amMos", core, parent)

	@property
	def utime(self):
		"""utime commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_utime'):
			from .Utime import Utime
			self._utime = Utime(self._core, self._cmd_group)
		return self._utime

	# noinspection PyTypeChecker
	def get_azimuth(self) -> enums.Azimuth:
		"""SCPI: SCENario:PDW:AMMos:AZIMuth \n
		Snippet: value: enums.Azimuth = driver.scenario.pdw.amMos.get_azimuth() \n
		For method RsPulseSeq.Scenario.Pdw.typePyAMMos, defines whether the angle of the Rx antenna or the bearing is reported. \n
			:return: azimuth: RX| BEARing
		"""
		response = self._core.io.query_str('SCENario:PDW:AMMos:AZIMuth?')
		return Conversions.str_to_scalar_enum(response, enums.Azimuth)

	def set_azimuth(self, azimuth: enums.Azimuth) -> None:
		"""SCPI: SCENario:PDW:AMMos:AZIMuth \n
		Snippet: driver.scenario.pdw.amMos.set_azimuth(azimuth = enums.Azimuth.BEARing) \n
		For method RsPulseSeq.Scenario.Pdw.typePyAMMos, defines whether the angle of the Rx antenna or the bearing is reported. \n
			:param azimuth: RX| BEARing
		"""
		param = Conversions.enum_scalar_to_str(azimuth, enums.Azimuth)
		self._core.io.write(f'SCENario:PDW:AMMos:AZIMuth {param}')

	def get_frame(self) -> float:
		"""SCPI: SCENario:PDW:AMMos:FRAMe \n
		Snippet: value: float = driver.scenario.pdw.amMos.get_frame() \n
		Sets the frame length. \n
			:return: frame: float Range: 50 to 500
		"""
		response = self._core.io.query_str('SCENario:PDW:AMMos:FRAMe?')
		return Conversions.str_to_float(response)

	def set_frame(self, frame: float) -> None:
		"""SCPI: SCENario:PDW:AMMos:FRAMe \n
		Snippet: driver.scenario.pdw.amMos.set_frame(frame = 1.0) \n
		Sets the frame length. \n
			:param frame: float Range: 50 to 500
		"""
		param = Conversions.decimal_value_to_str(frame)
		self._core.io.write(f'SCENario:PDW:AMMos:FRAMe {param}')

	def get_ppdw(self) -> bool:
		"""SCPI: SCENario:PDW:AMMos:PPDW \n
		Snippet: value: bool = driver.scenario.pdw.amMos.get_ppdw() \n
		If enabled, the format of the AMMOS file is set to PPDW. Otherwise PDW is assumed. \n
			:return: ppdw: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:PDW:AMMos:PPDW?')
		return Conversions.str_to_bool(response)

	def set_ppdw(self, ppdw: bool) -> None:
		"""SCPI: SCENario:PDW:AMMos:PPDW \n
		Snippet: driver.scenario.pdw.amMos.set_ppdw(ppdw = False) \n
		If enabled, the format of the AMMOS file is set to PPDW. Otherwise PDW is assumed. \n
			:param ppdw: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(ppdw)
		self._core.io.write(f'SCENario:PDW:AMMos:PPDW {param}')

	def clone(self) -> 'AmMos':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AmMos(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Level:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def get_range(self) -> float:
		"""SCPI: WAVeform:BEMitter:LEVel:RANGe \n
		Snippet: value: float = driver.waveform.bemitter.level.get_range() \n
		Sets the maximum level difference between the strongest and the weakest emitter. \n
			:return: range_py: float Range: 0 to 90
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:LEVel:RANGe?')
		return Conversions.str_to_float(response)

	def set_range(self, range_py: float) -> None:
		"""SCPI: WAVeform:BEMitter:LEVel:RANGe \n
		Snippet: driver.waveform.bemitter.level.set_range(range_py = 1.0) \n
		Sets the maximum level difference between the strongest and the weakest emitter. \n
			:param range_py: float Range: 0 to 90
		"""
		param = Conversions.decimal_value_to_str(range_py)
		self._core.io.write(f'WAVeform:BEMitter:LEVel:RANGe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmStep:
	"""AmStep commands group definition. 8 total commands, 1 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("amStep", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def clear(self) -> None:
		"""SCPI: PULSe:MOP:AMSTep:CLEar \n
		Snippet: driver.pulse.mop.amStep.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'PULSe:MOP:AMSTep:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: PULSe:MOP:AMSTep:CLEar \n
		Snippet: driver.pulse.mop.amStep.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'PULSe:MOP:AMSTep:CLEar', opc_timeout_ms)

	def get_count(self) -> float:
		"""SCPI: PULSe:MOP:AMSTep:COUNt \n
		Snippet: value: float = driver.pulse.mop.amStep.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('PULSe:MOP:AMSTep:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: PULSe:MOP:AMSTep:DELete \n
		Snippet: driver.pulse.mop.amStep.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'PULSe:MOP:AMSTep:DELete {param}')

	def get_duration(self) -> float:
		"""SCPI: PULSe:MOP:AMSTep:DURation \n
		Snippet: value: float = driver.pulse.mop.amStep.get_duration() \n
		Sets the step time. \n
			:return: duration: float Range: 0 to 3600, Unit: s
		"""
		response = self._core.io.query_str('PULSe:MOP:AMSTep:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: PULSe:MOP:AMSTep:DURation \n
		Snippet: driver.pulse.mop.amStep.set_duration(duration = 1.0) \n
		Sets the step time. \n
			:param duration: float Range: 0 to 3600, Unit: s
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'PULSe:MOP:AMSTep:DURation {param}')

	def set_insert(self, insert: float) -> None:
		"""SCPI: PULSe:MOP:AMSTep:INSert \n
		Snippet: driver.pulse.mop.amStep.set_insert(insert = 1.0) \n
		Inserts a new item before the selected one. \n
			:param insert: float
		"""
		param = Conversions.decimal_value_to_str(insert)
		self._core.io.write(f'PULSe:MOP:AMSTep:INSert {param}')

	def get_level(self) -> float:
		"""SCPI: PULSe:MOP:AMSTep:LEVel \n
		Snippet: value: float = driver.pulse.mop.amStep.get_level() \n
		Sets the step level. \n
			:return: level: float Range: -100 to 0
		"""
		response = self._core.io.query_str('PULSe:MOP:AMSTep:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: PULSe:MOP:AMSTep:LEVel \n
		Snippet: driver.pulse.mop.amStep.set_level(level = 1.0) \n
		Sets the step level. \n
			:param level: float Range: -100 to 0
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'PULSe:MOP:AMSTep:LEVel {param}')

	def get_select(self) -> float:
		"""SCPI: PULSe:MOP:AMSTep:SELect \n
		Snippet: value: float = driver.pulse.mop.amStep.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('PULSe:MOP:AMSTep:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: PULSe:MOP:AMSTep:SELect \n
		Snippet: driver.pulse.mop.amStep.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'PULSe:MOP:AMSTep:SELect {param}')

	def clone(self) -> 'AmStep':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AmStep(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Path:
	"""Path commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def get_calculated(self) -> str:
		"""SCPI: PROGram:PATH:CALCulated \n
		Snippet: value: str = driver.program.path.get_calculated() \n
		Sets the directory that holds the calculated waveforms. \n
			:return: calculated: string
		"""
		response = self._core.io.query_str('PROGram:PATH:CALCulated?')
		return trim_str_response(response)

	def set_calculated(self, calculated: str) -> None:
		"""SCPI: PROGram:PATH:CALCulated \n
		Snippet: driver.program.path.set_calculated(calculated = '1') \n
		Sets the directory that holds the calculated waveforms. \n
			:param calculated: string
		"""
		param = Conversions.value_to_quoted_str(calculated)
		self._core.io.write(f'PROGram:PATH:CALCulated {param}')

	def get_install(self) -> str:
		"""SCPI: PROGram:PATH:INSTall \n
		Snippet: value: str = driver.program.path.get_install() \n
		Queries the storage location for repository files. \n
			:return: install: string
		"""
		response = self._core.io.query_str('PROGram:PATH:INSTall?')
		return trim_str_response(response)

	def get_report(self) -> str:
		"""SCPI: PROGram:PATH:REPort \n
		Snippet: value: str = driver.program.path.get_report() \n
		Sets the directory that holds generated reports. \n
			:return: report: string
		"""
		response = self._core.io.query_str('PROGram:PATH:REPort?')
		return trim_str_response(response)

	def set_report(self, report: str) -> None:
		"""SCPI: PROGram:PATH:REPort \n
		Snippet: driver.program.path.set_report(report = '1') \n
		Sets the directory that holds generated reports. \n
			:param report: string
		"""
		param = Conversions.value_to_quoted_str(report)
		self._core.io.write(f'PROGram:PATH:REPort {param}')

	def get_volatile(self) -> str:
		"""SCPI: PROGram:PATH:VOLatile \n
		Snippet: value: str = driver.program.path.get_volatile() \n
		Sets the directory that holds volatile data. \n
			:return: volatile: string
		"""
		response = self._core.io.query_str('PROGram:PATH:VOLatile?')
		return trim_str_response(response)

	def set_volatile(self, volatile: str) -> None:
		"""SCPI: PROGram:PATH:VOLatile \n
		Snippet: driver.program.path.set_volatile(volatile = '1') \n
		Sets the directory that holds volatile data. \n
			:param volatile: string
		"""
		param = Conversions.value_to_quoted_str(volatile)
		self._core.io.write(f'PROGram:PATH:VOLatile {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Barker:
	"""Barker commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("barker", core, parent)

	def get_blank(self) -> bool:
		"""SCPI: PULSe:MOP:BARKer:BLANk \n
		Snippet: value: bool = driver.pulse.mop.barker.get_blank() \n
		Blanks out the signal during the transition time. \n
			:return: blank: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:BARKer:BLANk?')
		return Conversions.str_to_bool(response)

	def set_blank(self, blank: bool) -> None:
		"""SCPI: PULSe:MOP:BARKer:BLANk \n
		Snippet: driver.pulse.mop.barker.set_blank(blank = False) \n
		Blanks out the signal during the transition time. \n
			:param blank: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(blank)
		self._core.io.write(f'PULSe:MOP:BARKer:BLANk {param}')

	# noinspection PyTypeChecker
	def get_code(self) -> enums.BarkerCode:
		"""SCPI: PULSe:MOP:BARKer:CODE \n
		Snippet: value: enums.BarkerCode = driver.pulse.mop.barker.get_code() \n
		Selects the code sequence. \n
			:return: code: R2A| R2B| R3| R4A| R4B| R5| R7| R11| R13
		"""
		response = self._core.io.query_str('PULSe:MOP:BARKer:CODE?')
		return Conversions.str_to_scalar_enum(response, enums.BarkerCode)

	def set_code(self, code: enums.BarkerCode) -> None:
		"""SCPI: PULSe:MOP:BARKer:CODE \n
		Snippet: driver.pulse.mop.barker.set_code(code = enums.BarkerCode.R11) \n
		Selects the code sequence. \n
			:param code: R2A| R2B| R3| R4A| R4B| R5| R7| R11| R13
		"""
		param = Conversions.enum_scalar_to_str(code, enums.BarkerCode)
		self._core.io.write(f'PULSe:MOP:BARKer:CODE {param}')

	def get_ttime(self) -> float:
		"""SCPI: PULSe:MOP:BARKer:TTIMe \n
		Snippet: value: float = driver.pulse.mop.barker.get_ttime() \n
		Sets the transition time. \n
			:return: ttime: float Range: 0 to 50, Unit: percent
		"""
		response = self._core.io.query_str('PULSe:MOP:BARKer:TTIMe?')
		return Conversions.str_to_float(response)

	def set_ttime(self, ttime: float) -> None:
		"""SCPI: PULSe:MOP:BARKer:TTIMe \n
		Snippet: driver.pulse.mop.barker.set_ttime(ttime = 1.0) \n
		Sets the transition time. \n
			:param ttime: float Range: 0 to 50, Unit: percent
		"""
		param = Conversions.decimal_value_to_str(ttime)
		self._core.io.write(f'PULSe:MOP:BARKer:TTIMe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scan:
	"""Scan commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scan", core, parent)

	def clear(self) -> None:
		"""SCPI: EMITter:MODE:SCAN:CLEar \n
		Snippet: driver.emitter.mode.scan.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'EMITter:MODE:SCAN:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: EMITter:MODE:SCAN:CLEar \n
		Snippet: driver.emitter.mode.scan.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'EMITter:MODE:SCAN:CLEar', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: EMITter:MODE:SCAN \n
		Snippet: value: str = driver.emitter.mode.scan.get_value() \n
		Assigns an antenna scan, see method RsPulseSeq.Scan.create. \n
			:return: scan: string
		"""
		response = self._core.io.query_str('EMITter:MODE:SCAN?')
		return trim_str_response(response)

	def set_value(self, scan: str) -> None:
		"""SCPI: EMITter:MODE:SCAN \n
		Snippet: driver.emitter.mode.scan.set_value(scan = '1') \n
		Assigns an antenna scan, see method RsPulseSeq.Scan.create. \n
			:param scan: string
		"""
		param = Conversions.value_to_quoted_str(scan)
		self._core.io.write(f'EMITter:MODE:SCAN {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Variable:
	"""Variable commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("variable", core, parent)

	def get_catalog(self) -> str:
		"""SCPI: ANTenna:MODel:PLUGin:VARiable:CATalog \n
		Snippet: value: str = driver.antenna.model.plugin.variable.get_catalog() \n
		Queries the variables used in the plugin. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('ANTenna:MODel:PLUGin:VARiable:CATalog?')
		return trim_str_response(response)

	def get_select(self) -> str:
		"""SCPI: ANTenna:MODel:PLUGin:VARiable:SELect \n
		Snippet: value: str = driver.antenna.model.plugin.variable.get_select() \n
		No command help available \n
			:return: select: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:PLUGin:VARiable:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: ANTenna:MODel:PLUGin:VARiable:SELect \n
		Snippet: driver.antenna.model.plugin.variable.set_select(select = '1') \n
		No command help available \n
			:param select: No help available
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'ANTenna:MODel:PLUGin:VARiable:SELect {param}')

	def get_value(self) -> str:
		"""SCPI: ANTenna:MODel:PLUGin:VARiable:VALue \n
		Snippet: value: str = driver.antenna.model.plugin.variable.get_value() \n
		No command help available \n
			:return: value: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:PLUGin:VARiable:VALue?')
		return trim_str_response(response)

	def set_value(self, value: str) -> None:
		"""SCPI: ANTenna:MODel:PLUGin:VARiable:VALue \n
		Snippet: driver.antenna.model.plugin.variable.set_value(value = '1') \n
		No command help available \n
			:param value: No help available
		"""
		param = Conversions.value_to_quoted_str(value)
		self._core.io.write(f'ANTenna:MODel:PLUGin:VARiable:VALue {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Envelope:
	"""Envelope commands group definition. 13 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("envelope", core, parent)

	@property
	def data(self):
		"""data commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._cmd_group)
		return self._data

	def get_equation(self) -> str:
		"""SCPI: PULSe:ENVelope:EQUation \n
		Snippet: value: str = driver.pulse.envelope.get_equation() \n
		Determines the envelope mathematically. \n
			:return: equation: string
		"""
		response = self._core.io.query_str('PULSe:ENVelope:EQUation?')
		return trim_str_response(response)

	def set_equation(self, equation: str) -> None:
		"""SCPI: PULSe:ENVelope:EQUation \n
		Snippet: driver.pulse.envelope.set_equation(equation = '1') \n
		Determines the envelope mathematically. \n
			:param equation: string
		"""
		param = Conversions.value_to_quoted_str(equation)
		self._core.io.write(f'PULSe:ENVelope:EQUation {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EnvelopeMode:
		"""SCPI: PULSe:ENVelope:MODE \n
		Snippet: value: enums.EnvelopeMode = driver.pulse.envelope.get_mode() \n
		Selects the type of the custom envelope function. \n
			:return: mode: DATA| EQUation
		"""
		response = self._core.io.query_str('PULSe:ENVelope:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EnvelopeMode)

	def set_mode(self, mode: enums.EnvelopeMode) -> None:
		"""SCPI: PULSe:ENVelope:MODE \n
		Snippet: driver.pulse.envelope.set_mode(mode = enums.EnvelopeMode.DATA) \n
		Selects the type of the custom envelope function. \n
			:param mode: DATA| EQUation
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.EnvelopeMode)
		self._core.io.write(f'PULSe:ENVelope:MODE {param}')

	def clone(self) -> 'Envelope':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Envelope(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	def get_bt(self) -> float:
		"""SCPI: PULSe:MOP:FILTer:BT \n
		Snippet: value: float = driver.pulse.mop.filterPy.get_bt() \n
		Sets the B x T filter parameter. \n
			:return: bt: float Range: 0.15 to 2.5
		"""
		response = self._core.io.query_str('PULSe:MOP:FILTer:BT?')
		return Conversions.str_to_float(response)

	def set_bt(self, bt: float) -> None:
		"""SCPI: PULSe:MOP:FILTer:BT \n
		Snippet: driver.pulse.mop.filterPy.set_bt(bt = 1.0) \n
		Sets the B x T filter parameter. \n
			:param bt: float Range: 0.15 to 2.5
		"""
		param = Conversions.decimal_value_to_str(bt)
		self._core.io.write(f'PULSe:MOP:FILTer:BT {param}')

	def get_bandwidth(self) -> float:
		"""SCPI: PULSe:MOP:FILTer:BWIDth \n
		Snippet: value: float = driver.pulse.mop.filterPy.get_bandwidth() \n
		Sets the transition bandwidth of the filter. \n
			:return: bwidth: float Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:FILTer:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bwidth: float) -> None:
		"""SCPI: PULSe:MOP:FILTer:BWIDth \n
		Snippet: driver.pulse.mop.filterPy.set_bandwidth(bwidth = 1.0) \n
		Sets the transition bandwidth of the filter. \n
			:param bwidth: float Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(bwidth)
		self._core.io.write(f'PULSe:MOP:FILTer:BWIDth {param}')

	def get_length(self) -> float:
		"""SCPI: PULSe:MOP:FILTer:LENGth \n
		Snippet: value: float = driver.pulse.mop.filterPy.get_length() \n
		Sets the filter length. \n
			:return: length: integer Range: 1 to 64
		"""
		response = self._core.io.query_str('PULSe:MOP:FILTer:LENGth?')
		return Conversions.str_to_float(response)

	def set_length(self, length: float) -> None:
		"""SCPI: PULSe:MOP:FILTer:LENGth \n
		Snippet: driver.pulse.mop.filterPy.set_length(length = 1.0) \n
		Sets the filter length. \n
			:param length: integer Range: 1 to 64
		"""
		param = Conversions.decimal_value_to_str(length)
		self._core.io.write(f'PULSe:MOP:FILTer:LENGth {param}')

	def get_rolloff(self) -> float:
		"""SCPI: PULSe:MOP:FILTer:ROLLoff \n
		Snippet: value: float = driver.pulse.mop.filterPy.get_rolloff() \n
		Sets the roll off factor. \n
			:return: rolloff: float Range: 0.05 to 1
		"""
		response = self._core.io.query_str('PULSe:MOP:FILTer:ROLLoff?')
		return Conversions.str_to_float(response)

	def set_rolloff(self, rolloff: float) -> None:
		"""SCPI: PULSe:MOP:FILTer:ROLLoff \n
		Snippet: driver.pulse.mop.filterPy.set_rolloff(rolloff = 1.0) \n
		Sets the roll off factor. \n
			:param rolloff: float Range: 0.05 to 1
		"""
		param = Conversions.decimal_value_to_str(rolloff)
		self._core.io.write(f'PULSe:MOP:FILTer:ROLLoff {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.FilterType:
		"""SCPI: PULSe:MOP:FILTer:TYPE \n
		Snippet: value: enums.FilterType = driver.pulse.mop.filterPy.get_type_py() \n
		Selects the filter type. \n
			:return: type_py: NONE| RECTangular| COS| RCOS| GAUSs| LPASs| FSKGauss| SOQPsk| SMWRect
		"""
		response = self._core.io.query_str('PULSe:MOP:FILTer:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FilterType)

	def set_type_py(self, type_py: enums.FilterType) -> None:
		"""SCPI: PULSe:MOP:FILTer:TYPE \n
		Snippet: driver.pulse.mop.filterPy.set_type_py(type_py = enums.FilterType.COS) \n
		Selects the filter type. \n
			:param type_py: NONE| RECTangular| COS| RCOS| GAUSs| LPASs| FSKGauss| SOQPsk| SMWRect
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.FilterType)
		self._core.io.write(f'PULSe:MOP:FILTer:TYPE {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Shape:
	"""Shape commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shape", core, parent)

	# noinspection PyTypeChecker
	def get_base(self) -> enums.BaseDomain:
		"""SCPI: IPM:SHAPe:BASE \n
		Snippet: value: enums.BaseDomain = driver.ipm.shape.get_base() \n
		Defines the way the list items are processed. \n
			:return: base: PULSe| TIME
		"""
		response = self._core.io.query_str('IPM:SHAPe:BASE?')
		return Conversions.str_to_scalar_enum(response, enums.BaseDomain)

	def set_base(self, base: enums.BaseDomain) -> None:
		"""SCPI: IPM:SHAPe:BASE \n
		Snippet: driver.ipm.shape.set_base(base = enums.BaseDomain.PULSe) \n
		Defines the way the list items are processed. \n
			:param base: PULSe| TIME
		"""
		param = Conversions.enum_scalar_to_str(base, enums.BaseDomain)
		self._core.io.write(f'IPM:SHAPe:BASE {param}')

	def get_count(self) -> float:
		"""SCPI: IPM:SHAPe:COUNt \n
		Snippet: value: float = driver.ipm.shape.get_count() \n
		Sets the number of pulses for that the data from the list is used. \n
			:return: count: integer Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('IPM:SHAPe:COUNt?')
		return Conversions.str_to_float(response)

	def set_count(self, count: float) -> None:
		"""SCPI: IPM:SHAPe:COUNt \n
		Snippet: driver.ipm.shape.set_count(count = 1.0) \n
		Sets the number of pulses for that the data from the list is used. \n
			:param count: integer Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'IPM:SHAPe:COUNt {param}')

	# noinspection PyTypeChecker
	def get_interpol(self) -> enums.Interpolation:
		"""SCPI: IPM:SHAPe:INTerpol \n
		Snippet: value: enums.Interpolation = driver.ipm.shape.get_interpol() \n
		Enables a linear transition between the increments. \n
			:return: interpol: LINear| NONE
		"""
		response = self._core.io.query_str('IPM:SHAPe:INTerpol?')
		return Conversions.str_to_scalar_enum(response, enums.Interpolation)

	def set_interpol(self, interpol: enums.Interpolation) -> None:
		"""SCPI: IPM:SHAPe:INTerpol \n
		Snippet: driver.ipm.shape.set_interpol(interpol = enums.Interpolation.LINear) \n
		Enables a linear transition between the increments. \n
			:param interpol: LINear| NONE
		"""
		param = Conversions.enum_scalar_to_str(interpol, enums.Interpolation)
		self._core.io.write(f'IPM:SHAPe:INTerpol {param}')

	def get_period(self) -> float:
		"""SCPI: IPM:SHAPe:PERiod \n
		Snippet: value: float = driver.ipm.shape.get_period() \n
		Sets the period of time over that the list items are equally distributed. \n
			:return: period: float Range: 1e-09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:SHAPe:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: IPM:SHAPe:PERiod \n
		Snippet: driver.ipm.shape.set_period(period = 1.0) \n
		Sets the period of time over that the list items are equally distributed. \n
			:param period: float Range: 1e-09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'IPM:SHAPe:PERiod {param}')



"""RsPulseSeq instrument driver
	:version: 2.4.0.21
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '2.4.0.21'

# Main class
from RsPulseSeq.RsPulseSeq import RsPulseSeq

# Bin data format
from RsPulseSeq.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsPulseSeq.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsPulseSeq.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsPulseSeq.Internal.ScpiLogger import LoggingMode

# enums
from RsPulseSeq import enums

# repcaps
from RsPulseSeq import repcap



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Direction:
	"""Direction commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("direction", core, parent)

	def get_away(self) -> bool:
		"""SCPI: RECeiver:ANTenna:DIRection:AWAY \n
		Snippet: value: bool = driver.receiver.antenna.direction.get_away() \n
		Sets the azimuth automatically, so that the beam axis is radial to the receiver origin. \n
			:return: away: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:DIRection:AWAY?')
		return Conversions.str_to_bool(response)

	def set_away(self, away: bool) -> None:
		"""SCPI: RECeiver:ANTenna:DIRection:AWAY \n
		Snippet: driver.receiver.antenna.direction.set_away(away = False) \n
		Sets the azimuth automatically, so that the beam axis is radial to the receiver origin. \n
			:param away: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(away)
		self._core.io.write(f'RECeiver:ANTenna:DIRection:AWAY {param}')

	def get_azimuth(self) -> float:
		"""SCPI: RECeiver:ANTenna:DIRection:AZIMuth \n
		Snippet: value: float = driver.receiver.antenna.direction.get_azimuth() \n
		Turns the antenna beam axis. \n
			:return: azimuth: float Range: 0 to 360
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:DIRection:AZIMuth?')
		return Conversions.str_to_float(response)

	def set_azimuth(self, azimuth: float) -> None:
		"""SCPI: RECeiver:ANTenna:DIRection:AZIMuth \n
		Snippet: driver.receiver.antenna.direction.set_azimuth(azimuth = 1.0) \n
		Turns the antenna beam axis. \n
			:param azimuth: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(azimuth)
		self._core.io.write(f'RECeiver:ANTenna:DIRection:AZIMuth {param}')

	def get_elevation(self) -> float:
		"""SCPI: RECeiver:ANTenna:DIRection:ELEVation \n
		Snippet: value: float = driver.receiver.antenna.direction.get_elevation() \n
		Turns the antenna beam axis. \n
			:return: elevation: float Range: -90 to 90
		"""
		response = self._core.io.query_str('RECeiver:ANTenna:DIRection:ELEVation?')
		return Conversions.str_to_float(response)

	def set_elevation(self, elevation: float) -> None:
		"""SCPI: RECeiver:ANTenna:DIRection:ELEVation \n
		Snippet: driver.receiver.antenna.direction.set_elevation(elevation = 1.0) \n
		Turns the antenna beam axis. \n
			:param elevation: float Range: -90 to 90
		"""
		param = Conversions.decimal_value_to_str(elevation)
		self._core.io.write(f'RECeiver:ANTenna:DIRection:ELEVation {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Random:
	"""Random commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("random", core, parent)

	def get_reset(self) -> bool:
		"""SCPI: SEQuence:ITEM:IPM:RANDom:RESet \n
		Snippet: value: bool = driver.sequence.item.ipm.random.get_reset() \n
		Resets the start seed of random generator. \n
			:return: reset: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:RANDom:RESet?')
		return Conversions.str_to_bool(response)

	def set_reset(self, reset: bool) -> None:
		"""SCPI: SEQuence:ITEM:IPM:RANDom:RESet \n
		Snippet: driver.sequence.item.ipm.random.set_reset(reset = False) \n
		Resets the start seed of random generator. \n
			:param reset: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(reset)
		self._core.io.write(f'SEQuence:ITEM:IPM:RANDom:RESet {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Quesation:
	"""Quesation commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("quesation", core, parent)

	def get_condition(self) -> float:
		"""SCPI: STATus:QUESation:CONDition \n
		Snippet: value: float = driver.status.quesation.get_condition() \n
		No command help available \n
			:return: condition: No help available
		"""
		response = self._core.io.query_str('STATus:QUESation:CONDition?')
		return Conversions.str_to_float(response)

	def get_enable(self) -> bool:
		"""SCPI: STATus:QUESation:ENABle \n
		Snippet: value: bool = driver.status.quesation.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('STATus:QUESation:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: STATus:QUESation:ENABle \n
		Snippet: driver.status.quesation.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'STATus:QUESation:ENABle {param}')

	def get_event(self) -> float:
		"""SCPI: STATus:QUESation:EVENt \n
		Snippet: value: float = driver.status.quesation.get_event() \n
		No command help available \n
			:return: event: No help available
		"""
		response = self._core.io.query_str('STATus:QUESation:EVENt?')
		return Conversions.str_to_float(response)

	def get_ntransition(self) -> float:
		"""SCPI: STATus:QUESation:NTRansition \n
		Snippet: value: float = driver.status.quesation.get_ntransition() \n
		No command help available \n
			:return: ntransition: No help available
		"""
		response = self._core.io.query_str('STATus:QUESation:NTRansition?')
		return Conversions.str_to_float(response)

	def set_ntransition(self, ntransition: float) -> None:
		"""SCPI: STATus:QUESation:NTRansition \n
		Snippet: driver.status.quesation.set_ntransition(ntransition = 1.0) \n
		No command help available \n
			:param ntransition: No help available
		"""
		param = Conversions.decimal_value_to_str(ntransition)
		self._core.io.write(f'STATus:QUESation:NTRansition {param}')

	def get_ptransition(self) -> float:
		"""SCPI: STATus:QUESation:PTRansition \n
		Snippet: value: float = driver.status.quesation.get_ptransition() \n
		No command help available \n
			:return: ptransition: No help available
		"""
		response = self._core.io.query_str('STATus:QUESation:PTRansition?')
		return Conversions.str_to_float(response)

	def set_ptransition(self, ptransition: float) -> None:
		"""SCPI: STATus:QUESation:PTRansition \n
		Snippet: driver.status.quesation.set_ptransition(ptransition = 1.0) \n
		No command help available \n
			:param ptransition: No help available
		"""
		param = Conversions.decimal_value_to_str(ptransition)
		self._core.io.write(f'STATus:QUESation:PTRansition {param}')
